@@ -21,3 +21,14 @@ export const ENCOUNTER_TYPE_LABELS = {
 };
 
 export const ENCOUNTER_TYPE_VALUES = Object.values(ENCOUNTER_TYPES);
+
+export const ENCOUNTER_TYPE_ABBREVIATION_LABELS = {
+  [ENCOUNTER_TYPES.ADMISSION]: 'HA',
+  [ENCOUNTER_TYPES.TRIAGE]: 'T',
+  [ENCOUNTER_TYPES.CLINIC]: 'C',
+  [ENCOUNTER_TYPES.IMAGING]: 'I',
+  [ENCOUNTER_TYPES.EMERGENCY]: 'ESS',
+  [ENCOUNTER_TYPES.OBSERVATION]: 'AEP',
+  [ENCOUNTER_TYPES.SURVEY_RESPONSE]: 'FR',
+  [ENCOUNTER_TYPES.VACCINATION]: 'VR',
+};
