@@ -1,4 +1,4 @@
-import { DataTypes } from 'sequelize';
+import { DataTypes, Sequelize } from 'sequelize';
 import { SYNC_DIRECTIONS } from '@tamanu/constants';
 import { Model } from './Model';
 import type { InitOptions, Models } from '../types/model';
@@ -10,10 +10,15 @@ export class OneTimeLogin extends Model {
   declare usedAt?: Date;
   declare userId: string;
 
-  static initModel({ primaryKey, ...options }: InitOptions) {
+  static initModel(options: InitOptions) {
     super.init(
       {
-        id: primaryKey,
+        id: {
+          type: DataTypes.UUID,
+          allowNull: false,
+          primaryKey: true,
+          defaultValue: Sequelize.fn('gen_random_uuid'),
+        },
         token: { type: DataTypes.STRING, allowNull: false },
         expiresAt: { type: DataTypes.DATE, allowNull: false },
         usedAt: { type: DataTypes.DATE, allowNull: true },
