@@ -6,6 +6,7 @@ export const GLOBAL_EXCLUDE_TABLES = [
 export const NON_SYNCING_TABLES = [
   'logs.debug_logs',
   'logs.fhir_writes',
+  'public.devices',
   'public.fhir_materialise_jobs',
   'public.local_system_facts',
   'public.one_time_logins',
@@ -13,12 +14,13 @@ export const NON_SYNCING_TABLES = [
   'public.refresh_tokens',
   'public.signers',
   'public.sync_device_ticks',
-  'public.sync_lookup_ticks',
   'public.sync_lookup',
+  'public.sync_lookup_ticks',
   'public.sync_queued_devices',
   'public.sync_sessions',
   'public.user_localisation_caches',
   'public.user_recently_viewed_patients',
+  'public.portal_one_time_tokens',
 ];
 
 export const NON_LOGGED_TABLES = [
